import re

parse_host_header = re.compile(r"^(?P<host>[^:]+|\[.+\])(?::(?P<port>\d+))?$")

bad_headers = ["Keep-Alive", "Set-Cookie", "X-Powered-By", "Server", "Expires", "Cache-Control", "Pragma", "Age", "ETag", "Vary", "Strict-Transport-Security", "Alt-Svc", "Content-Security-Policy", "Feature-Policy", "X-Content-Type-Options", "X-Download-Options", "X-Frame-Options", "X-Permitted-Cross-Domain-Policies", "X-XSS-Protection", "Referrer-Policy", "CF-Cache-Status", "cf-request-id", "Expect-CT", "Report-To", "NEL", "CF-RAY"]

def request(flow):
	host_header = flow.request.host_header
	a = parse_host_header.match(host_header)
	if a:
		host_header = a.group("host").strip("[]")
		if a.group("port"):
			realport = int(a.group("port"))
			flow.request.port = realport
		elif flow.request.scheme == "http" and flow.request.port == 80:
			pass
		elif flow.request.scheme == "https" and flow.request.port == 699:
			flow.request.port = 443

def response(flow):

	flow.response.http_version = "HTTP/1.1"
	flow.response.headers["Connection"] = "close"

	for a in bad_headers:
		if a in flow.response.headers:
			flow.response.headers.pop(a, None)

	# This is unnecessary if the response is not compressed or chunked, but should future-proof against strange sets of transfer and/or content encodings.
	flow.response.raw_content = flow.response.content
	flow.response.headers["Content-Encoding"] = "identity"
	flow.response.headers["Transfer-Encoding"] = "identity"
	flow.response.headers["Content-Length"] = str(len(flow.response.content))
